@@ -50,10 +50,6 @@
 
 static CamelOfflineFolderClass *parent_class = NULL;
 
-static CamelProperty exchange_property_list[] = {
-	{ CAMEL_EXCHANGE_FOLDER_CHECK_FOLDER, "check_folder", N_("Always check for new mail in this folder") },
-};
-
 /* Returns the class for a CamelFolder */
 #define CF_CLASS(so) CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
@@ -67,6 +63,10 @@ static CamelMimeMessage *get_message         (CamelFolder *folder,
 static GPtrArray      *search_by_expression  (CamelFolder *folder,
 					      const char *exp,
 					      CamelException *ex);
+static guint32 	      count_by_expression  (CamelFolder *folder,
+					      const char *exp,
+					      CamelException *ex);
+
 static GPtrArray      *search_by_uids        (CamelFolder *folder,
 					      const char *expression,
 					      GPtrArray *uids,
@@ -86,9 +86,6 @@ static void   transfer_messages_the_hard_way (CamelFolder *source,
 static void refresh_info (CamelFolder *folder, CamelException *ex);
 static void exchange_sync (CamelFolder *folder, gboolean expunge, CamelException *ex);
 
-static int exchange_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
-static int exchange_setv (CamelObject *object, CamelException *ex, CamelArgV *args);
-
 static void
 class_init (CamelFolderClass *camel_folder_class)
 {
@@ -99,15 +96,14 @@ class_init (CamelFolderClass *camel_folder_class)
 	camel_folder_class->append_message = append_message;
 	camel_folder_class->get_message = get_message;
 	camel_folder_class->search_by_expression = search_by_expression;
+	camel_folder_class->count_by_expression = count_by_expression;
+
 	camel_folder_class->search_by_uids = search_by_uids;
 	/* use the default function for the search_free */
 	/* camel_folder_class->search_free = search_free; */
 	camel_folder_class->transfer_messages_to = transfer_messages_to;
 	camel_folder_class->refresh_info = refresh_info;
 	camel_folder_class->sync = exchange_sync;
-
- 	((CamelObjectClass *)camel_folder_class)->getv = exchange_getv;
-	((CamelObjectClass *)camel_folder_class)->setv = exchange_setv;
 }
 
 #define CAMEL_EXCHANGE_SERVER_FLAGS \
@@ -149,8 +145,6 @@ camel_exchange_folder_get_type (void)
 	static CamelType camel_exchange_folder_type = CAMEL_INVALID_TYPE;
 
 	if (camel_exchange_folder_type == CAMEL_INVALID_TYPE) {
-		int i;
-
 		camel_exchange_folder_type = camel_type_register (
 			camel_offline_folder_get_type (),
 			"CamelExchangeFolder",
@@ -160,10 +154,6 @@ camel_exchange_folder_get_type (void)
 			NULL,
 			(CamelObjectInitFunc) init,
 			(CamelObjectFinalizeFunc) finalize );
-
-		/* only localize here, do not create GSList, we do not want to leak */
-		for (i = 0; i < sizeof (exchange_property_list)/sizeof (exchange_property_list [0]); i++)
-			exchange_property_list [i].description = _(exchange_property_list [i].description);
 	}
 
 	return camel_exchange_folder_type;
@@ -174,14 +164,28 @@ refresh_info (CamelFolder *folder, CamelException *ex)
 {
 	CamelExchangeFolder *exch = CAMEL_EXCHANGE_FOLDER (folder);
 	CamelExchangeStore *store = CAMEL_EXCHANGE_STORE (folder->parent_store);
+	guint32 unread_count, visible_count;
 
 	if (camel_exchange_store_connected (store, ex)) {
 		camel_offline_journal_replay (exch->journal, NULL);
 
 		camel_stub_send (exch->stub, ex, CAMEL_STUB_CMD_REFRESH_FOLDER,
 				 CAMEL_STUB_ARG_FOLDER, folder->full_name,
-				 CAMEL_STUB_ARG_END);
+			     	 CAMEL_STUB_ARG_END);
 	}
+	
+	/* sync up the counts now */
+	if (!camel_stub_send (exch->stub, ex, CAMEL_STUB_CMD_SYNC_COUNT,
+				 CAMEL_STUB_ARG_FOLDER, folder->full_name,
+				 CAMEL_STUB_ARG_RETURN,
+			      	 CAMEL_STUB_ARG_UINT32, &unread_count,
+				 CAMEL_STUB_ARG_UINT32, &visible_count,
+			      	 CAMEL_STUB_ARG_END)){
+		g_print("\n Error syncing up the counts");
+	}
+
+	folder->summary->unread_count = unread_count;
+	folder->summary->visible_count = visible_count;
 }
 
 static void
@@ -475,6 +479,23 @@ search_by_expression (CamelFolder *folder, const char *expression,
 	return matches;
 }
 
+static guint32
+count_by_expression (CamelFolder *folder, const char *expression,
+		      CamelException *ex)
+{
+	CamelFolderSearch *search;
+	guint32 matches;
+
+	search = camel_exchange_search_new ();
+	camel_folder_search_set_folder (search, folder);
+	matches = camel_folder_search_count (search, expression, ex);
+
+	camel_object_unref (CAMEL_OBJECT (search));
+
+	return matches;
+}
+
+
 static GPtrArray *
 search_by_uids (CamelFolder *folder, const char *expression,
 		GPtrArray *uids, CamelException *ex)
@@ -747,6 +768,11 @@ camel_exchange_folder_add_message (CamelExchangeFolder *exch,
 
 	camel_folder_summary_add (folder->summary, info);
 
+	if (!(flags & CAMEL_MESSAGE_SEEN)) {
+		folder->summary->unread_count++;
+		folder->summary->visible_count++;
+	}
+
 	changes = camel_folder_change_info_new ();
 	camel_folder_change_info_add_uid (changes, uid);
 	camel_folder_change_info_recent_uid (changes, uid);
@@ -1034,7 +1060,7 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 
 		if (summary->len - camel_folder_summary_cache_size (folder->summary) > 50)
 			camel_folder_summary_reload_from_db (folder->summary, ex);
-		
+
 		for (i = 0; i < summary->len; i++) {
 			uids->pdata[i] = g_strdup(summary->pdata[i]);
 			info = camel_folder_summary_uid (folder->summary, uids->pdata[i]);
@@ -1083,7 +1109,7 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 		camel_operation_end (NULL);
 		if (!ok)
 			return FALSE;
-		
+
 		camel_folder_summary_save_to_db (folder->summary, ex);
 	}
 
@@ -1101,78 +1127,3 @@ exchange_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 
 	camel_folder_summary_save_to_db (folder->summary, ex);
 }
-
-static int
-exchange_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args)
-{
-	int i, count=0;
-	guint32 tag;
-
-	for (i = 0; i < args->argc; i++) {
-		CamelArgGet *arg = &args->argv[i];
-
-		tag = arg->tag;
-
-		switch (tag & CAMEL_ARG_TAG) {
-		case CAMEL_OBJECT_ARG_PERSISTENT_PROPERTIES:
-		case CAMEL_FOLDER_ARG_PROPERTIES: {
-			CamelArgGetV props;
-			int i;
-
-			props.argc = 1;
-			props.argv[0] = *arg;
-			((CamelObjectClass *)parent_class)->getv(object, ex, &props);
-
-			for (i = 0; i < sizeof (exchange_property_list)/sizeof (exchange_property_list [0]); i++)
-				*arg->ca_ptr = g_slist_append (*arg->ca_ptr, &exchange_property_list[i]);
-			break; }
-			/* exchange args */
-		case CAMEL_EXCHANGE_FOLDER_ARG_CHECK_FOLDER:
-			*arg->ca_int = ((CamelExchangeFolder *)object)->check_folder;
-			break;
-		default:
-			count++;
-			continue;
-		}
-
-		arg->tag = (tag & CAMEL_ARG_TYPE) | CAMEL_ARG_IGNORE;
-	}
-
-	if (count)
-		return ((CamelObjectClass *)parent_class)->getv (object, ex, args);
-
-	return 0;
-}
-
-static int
-exchange_setv (CamelObject *object, CamelException *ex, CamelArgV *args)
-{
-	int save = 0;
-	int i;
-	guint32 tag;
-
-	for (i = 0; i < args->argc; i++) {
-		CamelArg *arg = &args->argv[i];
-
-		tag = arg->tag;
-
-		switch (tag & CAMEL_ARG_TAG) {
-		case CAMEL_EXCHANGE_FOLDER_ARG_CHECK_FOLDER:
-			if (((CamelExchangeFolder *)object)->check_folder != arg->ca_int) {
-				((CamelExchangeFolder *)object)->check_folder = arg->ca_int;
-				save = 1;
-			}
-			break;
-		default:
-			continue;
-		}
-
-		arg->tag = (tag & CAMEL_ARG_TYPE) | CAMEL_ARG_IGNORE;
-	}
-
-	if (save)
-		camel_object_state_write (object);
-
-	return ((CamelObjectClass *)parent_class)->setv (object, ex, args);
-}
-
